@@ -1,23 +1,23 @@
 package Devel::InnerPackage;
 
 use strict;
-use base qw(Exporter);
-use vars qw($VERSION @EXPORT_OK);
+use Exporter 5.57 'import';
 
-$VERSION = '0.3';
-@EXPORT_OK = qw(list_packages);
+use if $] > 5.017, 'deprecate';
+
+our $VERSION = '0.4';
+our @EXPORT_OK = qw(list_packages);
 
 =pod
 
 =head1 NAME
 
-
 Devel::InnerPackage - find all the inner packages of a package
 
 =head1 SYNOPSIS
 
     use Foo::Bar;
-    use Devel::innerPackage qw(list_packages);
+    use Devel::InnerPackage qw(list_packages);
 
     my @inner_packages = list_packages('Foo::Bar');
 
@@ -70,12 +70,12 @@ sub list_packages {
             {
                 $cand =~ s!::$!!;
                 my @children = list_packages($pack.$cand);
-    
+
                 push @packs, "$pack$cand" unless $cand =~ /^::/ ||
                     !__PACKAGE__->_loaded($pack.$cand); # or @children;
                 push @packs, @children;
             }
-            return grep {$_ !~ /::::ISA::CACHE/} @packs;
+            return grep {$_ !~ /::(::ISA::CACHE|SUPER)/} @packs;
 }
 
 ### XXX this is an inlining of the Class-Inspector->loaded()
@@ -83,12 +83,12 @@ sub list_packages {
 sub _loaded {
        my ($class, $name) = @_;
 
-    no strict 'refs';
+        no strict 'refs';
 
        # Handle by far the two most common cases
        # This is very fast and handles 99% of cases.
        return 1 if defined ${"${name}::VERSION"};
-       return 1 if defined @{"${name}::ISA"};
+       return 1 if @{"${name}::ISA"};
 
        # Are there any symbol table entries other than other namespaces
        foreach ( keys %{"${name}::"} ) {
@@ -119,7 +119,7 @@ Distributed under the same terms as Perl itself.
 
 None known.
 
-=cut 
+=cut
 
 
 
